==> OpenOLAP_V1.0.1.zip: OpenOLAP/src/metatool/C5Panel.java <==
import java.util.*;
import java.awt.event.*;
import java.awt.*;

import javax.swing.*;
import javax.swing.border.*;	// {[_

public class C5Panel extends JPanel  implements GetPanelValue {
	public final static int ONE_SECOND = 1000;

	private JLabel comment; // p
	private JProgressBar progressBar;
	private javax.swing.Timer timer;
	private JTextArea taskOutput;
	private String newline = "\n";
	private String strWorkMessage = "";

	MTCreateTask mtCreateTask = null;

	JButton btnExit = null;
	JButton btnBack = null;
	JButton btnNext = null;

	// RXgN^
	public C5Panel(MTCreateTask mtct) {
		mtCreateTask = mtct;
		// Xy[X߂邪`͂ȂA̓߃{[_
		setBorder(new EmptyBorder(5,5,5,5));
		// wiF̕ύXiɕύXȂj
//		setBackground(Color.blue);
		// Ŝ̃CAEg}l[W{bNXCAEg(Y_AXIS)ɐݒ
		setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));

		// ----------------------------------------------------------------------------------------
		// Rg쐬
		comment = new JLabel("o");

		// ----------------------------------------------------------------------------------------
		// vOXo[쐬
		progressBar = new JProgressBar(0, mtCreateTask.getLengthOfTask());
		progressBar.setValue(0);
		progressBar.setStringPainted(true);

		// ----------------------------------------------------------------------------------------
		// o͕\peLXgGA쐬
		taskOutput = new JTextArea(5, 20);
		taskOutput.setMargin(new Insets(5,5,5,5));
		taskOutput.setEditable(false);

		this.add(comment);
		this.add(progressBar);
		this.add(new JScrollPane(taskOutput), BorderLayout.CENTER);

		//Create a timer.
		timer = new javax.swing.Timer(ONE_SECOND, new ActionListener() {
			public void actionPerformed(ActionEvent evt) {
				progressBar.setValue(mtCreateTask.getCurrent());
				//yCg
				progressBar.paintImmediately(progressBar.getVisibleRect());
				//\bZ[W̐ibZ[WωeLXgGAɒǉ\j
				if (!strWorkMessage.equals(mtCreateTask.getMessage())) {
					strWorkMessage = mtCreateTask.getMessage();
					taskOutput.append(strWorkMessage + newline);
				}
				taskOutput.setCaretPosition(
						taskOutput.getDocument().getLength());
				if (mtCreateTask.done()) {
					Toolkit.getDefaultToolkit().beep();
					timer.stop();
					//\
					taskOutput.append("SĂ̏I܂B" + newline);
					btnNext.setEnabled(true);
				} else if (mtCreateTask.getIntStatus() != 0) {
					Toolkit.getDefaultToolkit().beep();
					timer.stop();
					if (mtCreateTask.getIntStatus() == 1000) { /**** See method MTActualTask#execute() in MTCreateTask.java ****/
						// ^Ǘe[u`FbN
						MTDialogBox.showWarningDialog("MetaTool", mtCreateTask.getStringStatus());
					} else {
						//G[
						MTDialogBox.showDBErrorDialog("MetaTool", mtCreateTask.getStringStatus(), mtCreateTask.getIntStatus());
					}
					btnExit.setEnabled(true);
					btnBack.setEnabled(true);
				}
			}
		});

//		this.initialize();
	}// RXgN^iIj

	// I
	public Hashtable getValue() {
		Hashtable val = new Hashtable();
		return val;
	}

	public void leaveExitButton(JButton btn) {
		btnExit = btn;
	}
	public void leaveBackButton(JButton btn) {
		btnBack = btn;
	}
	public void leaveNextButton(JButton btn) {
		btnNext = btn;
	}
	public void clearTextArea() {
		taskOutput.setText("");
	}

	public void start() {
		//\
		strWorkMessage = mtCreateTask.getMessage();
		taskOutput.append(strWorkMessage + newline);
		//^C}[X^[g
		timer.start();
	}

}

==> OpenOLAP_V1.2.0.zip: OpenOLAP/src/metatool/C5Panel.java <==
import java.util.*;
import java.awt.event.*;
import java.awt.*;
import java.io.*;

import javax.swing.*;
import javax.swing.border.*;	// {[_

public class C5Panel extends JPanel  implements GetPanelValue {
	public final static int ONE_SECOND = 1000;

	private JLabel comment; // p
	private JProgressBar progressBar;
	private javax.swing.Timer timer;
	private JTextArea taskOutput;
	private String newline = "\n";
	private String strWorkMessage = "";

	MTCreateTask mtCreateTask = null;

	JButton btnExit = null;
	JButton btnBack = null;
	JButton btnNext = null;

	// RXgN^
	public C5Panel(MTCreateTask mtct) {
		mtCreateTask = mtct;
		// Xy[X߂邪`͂ȂA̓߃{[_
		setBorder(new EmptyBorder(5,5,5,5));
		// wiF̕ύXiɕύXȂj
//		setBackground(Color.blue);
		// Ŝ̃CAEg}l[W{bNXCAEg(Y_AXIS)ɐݒ
		setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));

		// ----------------------------------------------------------------------------------------
		// Rg쐬
		comment = new JLabel("o");

		// ----------------------------------------------------------------------------------------
		// vOXo[쐬
		progressBar = new JProgressBar(0, mtCreateTask.getLengthOfTask());
		progressBar.setValue(0);
		progressBar.setStringPainted(true);

		// ----------------------------------------------------------------------------------------
		// o͕\peLXgGA쐬
		taskOutput = new JTextArea(5, 20);
		taskOutput.setMargin(new Insets(5,5,5,5));
		taskOutput.setEditable(false);

		this.add(comment);
		this.add(progressBar);
		this.add(new JScrollPane(taskOutput), BorderLayout.CENTER);

		//Create a timer.
		timer = new javax.swing.Timer(ONE_SECOND, new ActionListener() {
			public void actionPerformed(ActionEvent evt) {
				progressBar.setValue(mtCreateTask.getCurrent());
				//yCg
				progressBar.paintImmediately(progressBar.getVisibleRect());
				//\bZ[W̐ibZ[WωeLXgGAɒǉ\j
				if (!strWorkMessage.equals(mtCreateTask.getMessage())) {
					strWorkMessage = mtCreateTask.getMessage();
					taskOutput.append(strWorkMessage + newline);
				}
				taskOutput.setCaretPosition(
						taskOutput.getDocument().getLength());
				if (mtCreateTask.done()) {
					Toolkit.getDefaultToolkit().beep();
					timer.stop();
					//\

					File file = new File("metaTool.log");

					if(file.exists()){
						taskOutput.append("G[܂B" + newline + "ڍׂ́umetaTool.logvQƂĂB" + newline);
					}else{
						taskOutput.append("SĂ̏I܂B" + newline);
					}

					btnNext.setEnabled(true);
				} else if (mtCreateTask.getIntStatus() != 0) {
					Toolkit.getDefaultToolkit().beep();
					timer.stop();
					if (mtCreateTask.getIntStatus() == 1000) { /**** See method MTActualTask#execute() in MTCreateTask.java ****/
						// ^Ǘe[u`FbN
						MTDialogBox.showWarningDialog("MetaTool", mtCreateTask.getStringStatus());
					} else {
						//G[
						MTDialogBox.showDBErrorDialog("MetaTool", mtCreateTask.getStringStatus(), mtCreateTask.getIntStatus());
					}
					btnExit.setEnabled(true);
					btnBack.setEnabled(true);
				}
			}
		});

//		this.initialize();
	}// RXgN^iIj

	// I
	public Hashtable getValue() {
		Hashtable val = new Hashtable();
		return val;
	}

	public void leaveExitButton(JButton btn) {
		btnExit = btn;
	}
	public void leaveBackButton(JButton btn) {
		btnBack = btn;
	}
	public void leaveNextButton(JButton btn) {
		btnNext = btn;
	}
	public void clearTextArea() {
		taskOutput.setText("");
	}

	public void start() {
		//\
		strWorkMessage = mtCreateTask.getMessage();
		taskOutput.append(strWorkMessage + newline);
		//^C}[X^[g
		timer.start();
	}

}
